@@ -1,6 +1,6 @@
 /*
     IA32
-    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,21 +18,7 @@
 #include "asycfilt.h"
 
 
-/* DllCanUnloadNow ordinal = 1, argument = 0 */
-static gboolean asycfilt_DllCanUnloadNow (Ia32Thread *thread)
-{
-  return FALSE;
-}
-
-
-/* FilterCreateInstance ordinal = 2, argument = 20 */
-static gboolean asycfilt_FilterCreateInstance (Ia32Thread *thread)
-{
-  return FALSE;
-}
-
-
 Ia32Export ia32_asycfilt_exports[] = {
-{ 0,    1, "DllCanUnloadNow",      asycfilt_DllCanUnloadNow},
-{20,    2, "FilterCreateInstance", asycfilt_FilterCreateInstance},
-{ 0,    0, NULL,                   NULL}};
+{ 0, 1, "DllCanUnloadNow",      NULL},
+{20, 2, "FilterCreateInstance", NULL},
+{G_MAXINT, 0, NULL, NULL}};
