@@ -1,6 +1,6 @@
 /*
     peimage
-    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2013 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "peimage.h"
-#include "misc/fileio.h"
 
 
 /******************************************************************************
@@ -102,23 +101,21 @@ peimage_file_load (const gchar *file)
 {
   guint8 *image;
   gint i, sections, alignment;
-  gssize length, header_bytes, size_of_image;
-  FileIO *fio;
+  gsize length, header_bytes, size_of_image;
   ImageSectionHeader *ish;
+  FILE *fp;
 
   if (!file)
     return NULL;
-  fio = fileio_open (file, FILEIO_ACCESS_READ, FILEIO_SHARE_READ,
-                                                    FILEIO_MODE_OPEN_EXISTING);
-  if (!fio)
+  fp = g_fopen (file, "rb");
+  if (!fp)
     return NULL;
   image = g_malloc (sizeof (ImageDosHeader));
-  if (!image || fileio_read (fio, image, sizeof (ImageDosHeader))
-                                                    != sizeof (ImageDosHeader)
+  if (!image || fread (image, sizeof (ImageDosHeader), 1, fp) != 1
                         || pe_idh_get_magic (image) != PEIMAGE_DOS_SIGNATURE)
     {
       g_free (image);
-      fileio_close (fio);
+      fclose (fp);
       return NULL;
     }
   length = idh_get_lfanew (image) + sizeof (guint32)
@@ -127,11 +124,11 @@ peimage_file_load (const gchar *file)
     {
       image = g_realloc (image, length);
       length -= sizeof (ImageDosHeader);
-      if (!image || fileio_read (fio, image + sizeof (ImageDosHeader), length)
-                                                                    != length)
+      if (!image || fread (image + sizeof (ImageDosHeader),
+                                        sizeof (guint8), length, fp) != length)
         {
           g_free (image);
-          fileio_close (fio);
+          fclose (fp);
           return NULL;
         }
       length += sizeof (ImageDosHeader);
@@ -144,17 +141,18 @@ peimage_file_load (const gchar *file)
                 || pe_ifh_get_machine (image) != PEIMAGE_FILE_MACHINE_I386)
     {
       g_free (image);
-      fileio_close (fio);
+      fclose (fp);
       return NULL;
     }
   header_bytes = peimage_file_header_bytes (image);
   image = g_realloc (image, header_bytes);
   header_bytes -= length;
-  if (!image || fileio_read (fio, image + length, header_bytes) != header_bytes
+  if (!image || fread (image + length,
+                            sizeof (guint8), header_bytes, fp) != header_bytes
                 || pe_ioh_get_magic (image) != PEIMAGE_NT_OPTIONAL_HDR_MAGIC)
     {
       g_free (image);
-      fileio_close (fio);
+      fclose (fp);
       return NULL;
     }
   header_bytes += length;
@@ -183,7 +181,7 @@ peimage_file_load (const gchar *file)
   image = g_realloc (image, size_of_image);
   if (!image)
     {
-      fileio_close (fio);
+      fclose (fp);
       return NULL;
     }
   length = pe_ioh_get_size_of_headers (image);
@@ -196,10 +194,10 @@ peimage_file_load (const gchar *file)
   if (length > header_bytes)
     {
       length -= header_bytes;
-      if (fileio_read (fio, image + header_bytes, length) != length)
+      if (fread (image + header_bytes, sizeof (guint8), length, fp) != length)
         {
           g_free (image);
-          fileio_close (fio);
+          fclose (fp);
           return NULL;
         }
     }
@@ -209,13 +207,13 @@ peimage_file_load (const gchar *file)
       gint pointer;
 
       pointer = ish_get_pointer_to_raw_data (ish) / alignment * alignment;
-      if (fileio_seek (fio, pointer, FILEIO_SEEK_SET) >= 0)
-        fileio_read (fio, image + ish_get_virtual_address (ish),
+      if (fseek (fp, pointer, SEEK_SET) == 0)
+        length = fread (image + ish_get_virtual_address (ish), sizeof (guint8),
                             (ish_get_size_of_raw_data (ish) + alignment - 1)
-                                                    / alignment * alignment);
+                                                / alignment * alignment, fp);
       ish++;
     }
-  if (!fileio_close (fio))
+  if (fclose (fp) != 0)
     {
       g_free (image);
       return NULL;
